recent abstract method
Returns the most recent entries, newest first, up to limit.
Implementation
Future<List<AuditEntry>> recent({int limit = 100});
Returns the most recent entries, newest first, up to limit.
Future<List<AuditEntry>> recent({int limit = 100});