AuthorizationException class
The authenticated principal is not permitted to perform the action.
- Inheritance
-
- Object
- OmnyServerException
- AuthorizationException
Constructors
- AuthorizationException(String message)
-
Creates an authorization exception.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited