CurrentState class

The observed configuration of a node: what it currently advertises.

Annotations
  • @immutable

Constructors

CurrentState({NodeCapabilities capabilities = NodeCapabilities.empty})
Creates a current state.
const

Properties

capabilities → NodeCapabilities
The node's currently detected capabilities.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited