FormulaId class

Identity of a formula (an operational procedure such as docker or dart).

A formula id is a non-empty lower-case token (letters, digits, _, -, .). Equality is by value.

Constructors

FormulaId(String value)
Creates and validates a formula id.
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The raw formula identifier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override