FormulaRunResult class final

Node → Hub: the final result of a FormulaRun.

Constructors

FormulaRunResult({required String requestId, required FormulaResult result})
Creates a formula-run result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requestId String
Correlation id.
final
result FormulaResult
The structured result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Encodes to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> d) FormulaRunResult
Decodes from JSON.