FormulaStarted class final

A formula run started on a node.

Inheritance

Constructors

FormulaStarted(NodeId nodeId, String formula, String action, DateTime at)
Creates the event.
const

Properties

action String
The action being run.
final
at DateTime
When the event occurred (UTC).
finalinherited
formula String
The formula id.
final
hashCode int
The hash code for this object.
no setterinherited
nodeId NodeId
The target node.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
A stable event type discriminator (used in JSON / streaming).
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payload() Map<String, dynamic>
Event-specific payload fields.
override
toJson() Map<String, dynamic>
JSON form (type + payload).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited