MetricSample class

A persisted, timestamped metric sample for a node.

Constructors

MetricSample({required NodeId nodeId, required DateTime at, required NodeStatus status})
Creates a metric sample.
const

Properties

at DateTime
When the sample was captured.
final
hashCode int
The hash code for this object.
no setterinherited
nodeId NodeId
The node the sample belongs to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status NodeStatus
The status snapshot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited