NodeCapabilities class

The set of capabilities a node advertises, keyed by capability name.

Annotations
  • @immutable

Constructors

NodeCapabilities(List<Capability> capabilities)
Creates a capability set.
const

Properties

capabilities → List<Capability>
The advertised capabilities (de-duplicated by name).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

has(CapabilityKind kind) → bool
Whether a capability of kind is present.
hasNamed(String name) → bool
Whether a capability with name is present.
named(String name) → Capability?
Returns the capability with name, or null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
JSON form.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → NodeCapabilities
Decodes from JSON.

Constants

empty → const NodeCapabilities
An empty capability set.