NodeRepository class abstract

Persists the Hub's view of registered nodes.

All repositories are async (so SQLite / network backends fit) and are the designed seam for the in-memory, JSON-directory and SQLite implementations.

Implementers

Constructors

NodeRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

all() Future<List<NodeDescriptor>>
Returns all known nodes.
delete(NodeId id) Future<bool>
Deletes the node with id; returns true if a node was removed.
find(NodeId id) Future<NodeDescriptor?>
Returns the node with id, or null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(NodeDescriptor node) Future<void>
Inserts or replaces node.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited