OperationAck class final

A generic acknowledgement for a request that has no richer result type.

Constructors

OperationAck({required String requestId, required bool success, String message = ''})
Creates an ack.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
A message (especially on failure).
final
requestId → String
Correlation id.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
Whether the operation succeeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Encodes to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> d) → OperationAck
Decodes from JSON.