OperationStatus enum
Where an Operation has got to.
Values
- running → const OperationStatus
-
Dispatched to the node, still working.
- succeeded → const OperationStatus
-
Finished, and did what was asked.
- failed → const OperationStatus
-
Finished, and did not.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String value) → OperationStatus - Parses a status, rejecting anything else.
Constants
-
values
→ const List<
OperationStatus> - A constant List of the values in this enum, in order of their declaration.