Rollbackable class abstract mixin

Optional mixin for formulas that can roll back a failed action.

Constructors

Rollbackable()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rollback(FormulaAction action, FormulaContext context) Future<FormulaResult>
Attempts to undo the effects of a failed action.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited