usageFooter property
An optional footer for usage.
If a subclass overrides this to return a string, it will automatically be added to the end of usage.
Implementation
@override
String? get usageFooter => _usageExamples([
'omnyserver service install hub --cert certs/server.crt '
'--key certs/server.key --grant "alice:s3cr3t:admin"',
'omnyserver service install node --hub wss://hub:8443 --id web-01 '
'--token s3cr3t',
'omnyserver service install hub --system --tls-dir /etc/letsencrypt/live/hub',
'omnyserver service install node --hub wss://hub:8443 --id web-01 '
'--token s3cr3t --dry-run',
]);