usageFooter property

  1. @override
String? get usageFooter
override

An optional footer for usage.

If a subclass overrides this to return a string, it will automatically be added to the end of usage.

Implementation

@override
String? get usageFooter => _usageExamples([
  'omnyserver service reconfigure node --id web-01 --label region=eu',
  'omnyserver service reconfigure hub --cors-origin https://dash.example.com',
]);