usageFooter property
An optional footer for usage.
If a subclass overrides this to return a string, it will automatically be added to the end of usage.
Implementation
@override
String? get usageFooter => _usageExamples([
'omnyserver service reinstall hub',
'omnyserver service reinstall node --id web-01 --hub wss://hub:8443',
]);