tick method

void tick()

Re-checks pending offline breaches. An absence produces no events, so nothing else would ever notice that a node has now been gone long enough.

Implementation

void tick() {
  for (final rule in rules) {
    if (rule.metric != AlertMetric.offline) continue;
    for (final key in _breachedSince.keys.toList()) {
      if (!key.endsWith('${rule.id}')) continue;
      final nodeId = key.split('').first;
      _judge(nodeId: nodeId, rule: rule, breached: true, value: null);
    }
  }
}