AuthorizedKeysStore class

An in-memory trust store of authorized public keys, keyed by (principal, key).

Constructors

AuthorizedKeysStore([List<AuthorizedKey> entries = const []])
Creates a store from entries.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(AuthorizedKey entry) → void
Adds an entry to the store.
find(String principal, Ed25519PublicKey key) AuthorizedKey?
Finds the entry matching principal and key, or null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited