CompositeAuthenticator class
Tries several Authenticators in order, succeeding on the first that authenticates the credential.
Lets a Hub accept both token and public-key credentials. The credential shape (token vs public key) selects which authenticator can succeed.
- Implemented types
Constructors
-
CompositeAuthenticator(List<
Authenticator> delegates) -
Creates a composite over
delegates(tried in order).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
Credential credential, {required Uint8List challenge}) → Future< Principal> -
Authenticates
credential, returning the resolved principal.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited