JsonFormulaRepository class

JSON-directory FormulaRepository (<root>/formulas/<id>.json).

Implemented types

Constructors

JsonFormulaRepository(String path)
Creates a formula repository rooted at path.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

all() Future<List<FormulaSpec>>
Returns all formula specs.
override
delete(FormulaId id) Future<bool>
Deletes the formula spec with id; returns true if removed.
override
find(FormulaId id) Future<FormulaSpec?>
Returns the formula spec with id, or null.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(FormulaSpec spec) Future<void>
Inserts or replaces spec.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited