JsonNodeRepository class

JSON-directory NodeRepository (<root>/nodes/<id>.json).

Implemented types

Constructors

JsonNodeRepository(String path)
Creates a node repository rooted at path.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

all() Future<List<NodeDescriptor>>
Returns all known nodes.
override
delete(NodeId id) Future<bool>
Deletes the node with id; returns true if a node was removed.
override
find(NodeId id) Future<NodeDescriptor?>
Returns the node with id, or null.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(NodeDescriptor node) Future<void>
Inserts or replaces node.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited