recent method
Returns the most recent entries, newest first, up to limit.
Implementation
@override
Future<List<AuditEntry>> recent({int limit = 100}) async {
final out = _entries.reversed.take(limit).toList();
return out;
}
Returns the most recent entries, newest first, up to limit.
@override
Future<List<AuditEntry>> recent({int limit = 100}) async {
final out = _entries.reversed.take(limit).toList();
return out;
}