MemoryGrantRepository class

In-memory GrantRepository.

Implemented types

Constructors

MemoryGrantRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

all() Future<List<Grant>>
Every issued grant.
override
delete(String id) Future<bool>
Revokes the grant with id; returns true if one was removed.
override
find(String id) Future<Grant?>
The grant with id, or null.
override
findByTokenHash(String tokenHash) Future<Grant?>
The grant whose token hashes to tokenHash, or null.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(Grant grant) Future<void>
Inserts or replaces grant.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited