NodeEvent class

An observable change in the NodeRegistry.

Constructors

NodeEvent(NodeEventKind kind, NodeDescriptor descriptor, [RegisteredNode? node])
Creates a node event.
const

Properties

descriptor → NodeDescriptor
The affected node's descriptor.
final
hashCode int
The hash code for this object.
no setterinherited
kind NodeEventKind
What happened.
final
node RegisteredNode?
The affected registration, when the subscriber needs more than the descriptor — its RegisteredNode.connection, RegisteredNode.principal or RegisteredNode.state.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited