SqliteMetricRepository class

SQLite-backed MetricRepository.

Implemented types

Constructors

SqliteMetricRepository(Database db)
Creates the repository.

Properties

db → Database
The database handle.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recentFor(NodeId nodeId, {int limit = 100, DateTime? since}) Future<List<MetricSample>>
Returns recent samples for nodeId, newest first, up to limit.
override
record(MetricSample sample) Future<void>
Records a sample.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited