SqliteNodeRepository class
SQLite-backed NodeRepository.
- Implemented types
Constructors
- SqliteNodeRepository(Database db)
- Creates the repository.
Properties
- db → Database
-
The database handle.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
all(
) → Future< List< NodeDescriptor> > -
Returns all known nodes.
override
-
delete(
NodeId id) → Future< bool> -
Deletes the node with
id; returns true if a node was removed.override -
find(
NodeId id) → Future< NodeDescriptor?> -
Returns the node with
id, ornull.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
NodeDescriptor node) → Future< void> -
Inserts or replaces
node.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited