AgentState enum

The connection lifecycle state of a NodeAgent.

Inheritance
Available extensions

Values

connecting → const AgentState

Establishing the connection / performing the handshake.

connected → const AgentState

Connected, authenticated and registered with the Hub.

reconnecting → const AgentState

The connection dropped; backing off before the next attempt.

offline → const AgentState

Stopped and not attempting to reconnect.

authenticationFailed → const AgentState

Authentication was rejected; will not reconnect until reconfigured.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AgentState>
A constant List of the values in this enum, in order of their declaration.