CommandStep class
A platform command template: the executable and args to run for an action on a given OS family.
Constructors
-
CommandStep(String executable, List<
String> args) -
Creates a command step.
const
Properties
-
args
→ List<
String> -
The arguments.
final
- executable → String
-
The executable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited