spec property
The static metadata describing this formula.
Implementation
@override
// Defined in the domain, so the Hub can serve a catalogue of what nodes can
// do without importing the code that does it.
FormulaSpec get spec => dockerSpec;
The static metadata describing this formula.
@override
// Defined in the domain, so the Hub can serve a catalogue of what nodes can
// do without importing the code that does it.
FormulaSpec get spec => dockerSpec;