NodeServiceHandler class

Answers Hub ServiceControl requests on the node by driving a ServiceController (systemd / launchd / Windows Service Manager).

Provides a ServiceHandler for the agent config.

Constructors

NodeServiceHandler(ServiceController controller)
Creates a service handler over controller.
const

Properties

controller ServiceController
The OS service controller.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(ServiceControl request) Future<ServiceControlResult>
Handles a request, returning a result message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited