OpenClDetector class

Detects OpenCL support via clinfo (best effort).

Implemented types

Constructors

OpenClDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
kind CapabilityKind
The kind this detector probes for.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect() Future<Capability?>
Detects the capability, or returns null if not present.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited