brew property
Homebrew, on macOS. null where the commands are part of the system —
netstat and nslookup ship with macOS, and are nobody's to uninstall.
Implementation
final String? brew;
Homebrew, on macOS. null where the commands are part of the system —
netstat and nslookup ship with macOS, and are nobody's to uninstall.
final String? brew;