PublicKeyCredentialProvider class

A CredentialProvider that signs the challenge with an Ed25519 key pair.

Implemented types

Constructors

PublicKeyCredentialProvider({required String principal, required SimpleKeyPair keyPair})
Wraps an existing keyPair.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keyPair → SimpleKeyPair
The Ed25519 key pair used to sign challenges.
final
principal String
The principal this provider authenticates as.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provide({required Uint8List challenge}) Future<Credential>
Builds a credential answering challenge.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromSeed({required String principal, required List<int> seed}) Future<PublicKeyCredentialProvider>
Creates a provider from a 32-byte Ed25519 seed.