TokenCredentialProvider class

A CredentialProvider that presents a static bearer token.

Implemented types

Constructors

TokenCredentialProvider({required String principal, required String token})
Creates a token credential provider.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
principal String
The principal this provider authenticates as.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
The bearer token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provide({required Uint8List challenge}) Future<Credential>
Builds a credential answering challenge.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited