onRestartAgent property
Stops the agent in a way its supervisor will undo — the agent comes back.
Implementation
final Future<void> Function()? onRestartAgent;
Stops the agent in a way its supervisor will undo — the agent comes back.
final Future<void> Function()? onRestartAgent;