CapabilityDetector class abstract

Probes the host for a single capability, returning it if present.

Detectors are cheap, side-effect-free probes (run a --version, stat a device file, etc.). They return null when the capability is absent and must never throw for an absent capability.

Implementers

Constructors

CapabilityDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
kind CapabilityKind
The kind this detector probes for.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect() Future<Capability?>
Detects the capability, or returns null if not present.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited