CommandResult class final
Node → Hub: the result of a CommandRequest.
Constructors
- CommandResult({required String requestId, required int exitCode, String stdout = '', String stderr = ''})
-
Creates a command result.
const
Properties
- exitCode → int
-
The process exit code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId → String
-
Correlation id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → String
-
Captured stderr.
final
- stdout → String
-
Captured stdout.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Encodes to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> d) → CommandResult - Decodes from JSON.