CpuInfo class
CPU utilisation snapshot for a node.
- Annotations
-
- @immutable
Constructors
Properties
- coreCount → int
-
Number of logical cores.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
loadAverage
→ List<
double> -
Load averages over 1/5/15 minutes (may be empty on platforms without it).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usagePercent → double
-
Overall CPU usage as a percentage (0–100).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - JSON form.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited