ProcessInfo class
A running process snapshot and its resource consumption.
- Annotations
-
- @immutable
Constructors
- ProcessInfo({required int pid, required String name, required double cpuPercent, required int memoryBytes})
-
Creates a process snapshot.
const
Properties
- cpuPercent → double
-
CPU usage as a percentage (0–100).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- memoryBytes → int
-
Resident memory in bytes.
final
- name → String
-
Executable / command name.
final
- pid → int
-
Process id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - JSON form.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ProcessInfo - Decodes from JSON.