StatusReport class final
Node → Hub: a live status snapshot, pushed one-way.
Constructors
- StatusReport({required String nodeId, required NodeStatus status})
-
Creates a status report.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodeId → String
-
The reporting node's id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → NodeStatus
-
The snapshot.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Encodes to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> d) → StatusReport - Decodes from JSON.