ApiResponse class
A raw HTTP response: the status and the undecoded body.
Constructors
- ApiResponse(int statusCode, String body)
-
Creates a response.
const
Properties
- body → String
-
The response body as text (empty when there is none).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
The HTTP status code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited