AuthorizedKey class
An authorized public key entry: which principal it grants and the roles.
Constructors
-
AuthorizedKey({required String principal, required Ed25519PublicKey key, Set<
String> roles = const {}}) -
Creates an authorized key entry.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Ed25519PublicKey
-
The authorized public key.
final
- principal → String
-
The principal this key authenticates.
final
-
roles
→ Set<
String> -
Roles granted on successful authentication.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited