alertInterval property
How often pending offline alerts are re-checked.
An absence produces no events, so nothing else would ever notice that a node has now been gone long enough to be worth mentioning.
Implementation
final Duration alertInterval;
How often pending offline alerts are re-checked.
An absence produces no events, so nothing else would ever notice that a node has now been gone long enough to be worth mentioning.
final Duration alertInterval;