MemoryPresetRepository class
In-memory PresetRepository.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
all(
) → Future< List< Preset> > -
Returns all presets.
override
-
delete(
PresetId id) → Future< bool> -
Deletes the preset with
id; returns true if removed.override -
find(
PresetId id) → Future< Preset?> -
Returns the preset with
id, ornull.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
Preset preset) → Future< void> -
Inserts or replaces
preset.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited