SqliteAuditRepository class
SQLite-backed AuditRepository.
- Implemented types
Constructors
- SqliteAuditRepository(Database db)
- Creates the repository.
Properties
- db → Database
-
The database handle.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
append(
AuditEntry entry) → Future< void> -
Appends
entryto the trail.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recent(
{int limit = 100}) → Future< List< AuditEntry> > -
Returns the most recent entries, newest first, up to
limit.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited