ExecResult class
The result of running an external command.
Constructors
- ExecResult({required int exitCode, String stdout = '', String stderr = ''})
-
Creates an exec result.
const
Properties
- exitCode → int
-
The process exit code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ok → bool
-
Whether the command succeeded.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → String
-
Captured stderr.
final
- stdout → String
-
Captured stdout.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited