ProcessCommandExecutor class

The default CommandExecutor, backed by Process.run.

Implemented types

Constructors

ProcessCommandExecutor()
Creates a process-backed executor.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(String executable, List<String> args, {Map<String, String>? environment}) → Future<ExecResult>
Runs executable with args, returning the captured result.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited