ProviderRegistry class

The catalogue of resource types this node can actually handle.

Constructors

ProviderRegistry()
Creates an empty registry.
ProviderRegistry.of(Iterable<ResourceProvider> providers)
Creates a registry holding providers.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
providers Iterable<ResourceProvider>
Every registered provider.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

byType(String type) ResourceProvider?
The provider for type, or null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(ResourceProvider provider) → void
Registers (or replaces) provider.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited